@@ -1,5 +1,6 @@
 import numpy as np
 from sklearn.neighbors import KNeighborsClassifier as KNN
+import matplotlib.pyplot as plt
 
 class Solution():    
     #structure of the solution 
@@ -51,25 +52,28 @@ def initialize(num_agents, num_features):
 
 
 
-def sort_agents(agents, obj_function, data):
+def sort_agents(agents, obj, data, fitness=None):
     # sort the agents according to fitness
     train_X, val_X, train_Y, val_Y = data.train_X, data.val_X, data.train_Y, data.val_Y
+    (obj_function, weight_acc) = obj
+   
+    if fitness is None:
+        # if there is only one agent
+        if len(agents.shape) == 1:
+            num_agents = 1
+            fitness = obj_function(agents, train_X, val_X, train_Y, val_Y, weight_acc)
+            return agents, fitness
 
-    # if there is only one agent
-    if len(agents.shape) == 1:
-        num_agents = 1
-        fitness = obj_function(agents, train_X, val_X, train_Y, val_Y)
-        return agents, fitness
+        # for multiple agents
+        else:
+            num_agents = agents.shape[0]
+            fitness = np.zeros(num_agents)
+            for id, agent in enumerate(agents):
+                fitness[id] = obj_function(agent, train_X, val_X, train_Y, val_Y, weight_acc)
 
-    # for multiple agents
-    else:
-        num_agents = agents.shape[0]
-        fitness = np.zeros(num_agents)
-        for id, agent in enumerate(agents):
-            fitness[id] = obj_function(agent, train_X, val_X, train_Y, val_Y)
-        idx = np.argsort(-fitness)
-        sorted_agents = agents[idx].copy()
-        sorted_fitness = fitness[idx].copy()
+    idx = np.argsort(-fitness)
+    sorted_agents = agents[idx].copy()
+    sorted_fitness = fitness[idx].copy()
 
     return sorted_agents, sorted_fitness
 
@@ -108,15 +112,37 @@ def compute_accuracy(agent, train_X, test_X, train_Y, test_Y):
     return acc
         
 
-def compute_fitness(agent, train_X, test_X, train_Y, test_Y):
+def compute_fitness(agent, train_X, test_X, train_Y, test_Y, weight_acc=0.9):
     # compute a basic fitness measure
-    weight_acc = 0.7
-    weight_feat = 0.3
+    if(weight_acc == None):
+        weight_acc = 0.9
+
+    weight_feat = 1 - weight_acc
     num_features = agent.shape[0]
     
     acc = compute_accuracy(agent, train_X, test_X, train_Y, test_Y)
     feat = (num_features - np.sum(agent))/num_features
 
     fitness = weight_acc * acc + weight_feat * feat
+    return fitness
+
+
+def Conv_plot(convergence_curve):
+    # plot convergence curves
+    num_iter = len(convergence_curve['fitness'])
+    iters = np.arange(num_iter) + 1
+    fig, axes = plt.subplots(2, 1)
+    fig.tight_layout(pad = 5) 
+    fig.suptitle('Convergence Curves')
     
-    return fitness
\ No newline at end of file
+    axes[0].set_title('Convergence of Fitness over Iterations')
+    axes[0].set_xlabel('Iteration')
+    axes[0].set_ylabel('Fitness')
+    axes[0].plot(iters, convergence_curve['fitness'])
+
+    axes[1].set_title('Convergence of Feature Count over Iterations')
+    axes[1].set_xlabel('Iteration')
+    axes[1].set_ylabel('Number of Selected Features')
+    axes[1].plot(iters, convergence_curve['feature_count'])
+
+    return fig, axes
\ No newline at end of file
